{
    "$graph": [
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "id": "#fastqc-results-trigger.cwl",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#fastqc-results-trigger.cwl/fastqc_results_trigger/summary_file"
                }
            ],
            "expression": "${\n  var criteria_array = inputs.summary_file.contents.match(/.*Per base sequence quality.*|.*Per sequence quality scores.*|.*Overrepresented sequences.*|.*Adapter Content.*/g);\n  if (criteria_array.length > 0){\n    if (criteria_array.toString().match(/FAIL/g) != null){\n      return { \"trigger\": true };\n    } else {\n      return { \"trigger\": false };\n    }\n  } else {\n    return { \"trigger\": true };\n  }\n}",
            "outputs": [
                {
                    "type": "boolean",
                    "id": "#fastqc-results-trigger.cwl/fastqc_results_trigger/trigger"
                }
            ]
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/illumina_adapters_file"
                },
                {
                    "type": "File",
                    "id": "#main/sra_input_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/trimmomatic/upstream_trimmed_file",
                    "id": "#main/fastq"
                }
            ],
            "steps": [
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/sra_to_fastq/fastq_file_1",
                            "id": "#main/fastqc/fastq_file"
                        }
                    ],
                    "out": [
                        "#main/fastqc/summary_file"
                    ],
                    "id": "#main/fastqc"
                },
                {
                    "run": "#fastqc-results-trigger.cwl",
                    "in": [
                        {
                            "source": "#main/fastqc/summary_file",
                            "id": "#main/fastqc_results_trigger/summary_file"
                        }
                    ],
                    "out": [
                        "#main/fastqc_results_trigger/trigger"
                    ],
                    "id": "#main/fastqc_results_trigger"
                },
                {
                    "run": "#fastq-dump.cwl",
                    "in": [
                        {
                            "source": "#main/sra_input_file",
                            "id": "#main/sra_to_fastq/sra_file"
                        }
                    ],
                    "out": [
                        "#main/sra_to_fastq/fastq_file_1"
                    ],
                    "id": "#main/sra_to_fastq"
                },
                {
                    "run": "#trimmomatic.cwl",
                    "in": [
                        {
                            "source": "#main/illumina_adapters_file",
                            "id": "#main/trimmomatic/adapters_file"
                        },
                        {
                            "source": "#main/sra_to_fastq/fastq_file_1",
                            "id": "#main/trimmomatic/fastq_file_upstream"
                        },
                        {
                            "default": "2:30:15",
                            "id": "#main/trimmomatic/illuminaclip_step_param"
                        },
                        {
                            "default": "SE",
                            "id": "#main/trimmomatic/lib_type"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/trimmomatic/threads"
                        },
                        {
                            "source": "#main/fastqc_results_trigger/trigger",
                            "id": "#main/trimmomatic/trigger"
                        }
                    ],
                    "out": [
                        "#main/trimmomatic/upstream_trimmed_file"
                    ],
                    "id": "#main/trimmomatic"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/sratoolkit:v2.8.2-1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--aligned"
                    },
                    "doc": "Dump only aligned sequences\n",
                    "id": "#fastq-dump.cwl/aligned"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--aligned-region"
                    },
                    "doc": "Filter by position on genome.\nName can either be accession.version\n(ex:NC_000001.10) or file specific name\n(ex:\"chr1\" or \"1\"). \"from\" and \"to\" are 1-based coordinates\n",
                    "id": "#fastq-dump.cwl/aligned_region"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--clip"
                    },
                    "doc": "Clip adapter sequences\n",
                    "id": "#fastq-dump.cwl/clip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 34,
                        "prefix": "--defline-qual"
                    },
                    "doc": "Defline format specification for quality.\n<fmt> is string of characters and/or\nvariables. The variables can be one of: $ac\n- accession, $si spot id, $sn spot\nname, $sg spot group (barcode), $sl spot\nlength in bases, $ri read number, $rn\nread name, $rl read length in bases. '[]'\ncould be used for an optional output: if\nall vars in [] yield empty values whole\ngroup is not printed. Empty value is empty\nstring or for numeric variables. Ex:\n@$sn[_$rn]/$ri '_$rn' is omitted if name\nis empty\n",
                    "id": "#fastq-dump.cwl/defline_qual"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 33,
                        "prefix": "--defline-seq"
                    },
                    "doc": "Defline format specification for sequence.\n",
                    "id": "#fastq-dump.cwl/defline_seq"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 35,
                        "prefix": "--disable-multithreading"
                    },
                    "doc": "disable multithreading\n",
                    "id": "#fastq-dump.cwl/disable_multithreading"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 26,
                        "prefix": "--dumpbase"
                    },
                    "doc": "Formats sequence using base space (default\nfor other than SOLiD).\n",
                    "id": "#fastq-dump.cwl/dumpbase"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 25,
                        "prefix": "--dumpcs"
                    },
                    "doc": "Formats sequence using color space (default\nfor SOLiD),\"cskey\" may be specified for\ntranslation\n",
                    "id": "#fastq-dump.cwl/dumpcs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 28,
                        "prefix": "--fasta"
                    },
                    "doc": "FASTA only, no qualities, optional line\nwrap width (set to zero for no wrapping)\n",
                    "id": "#fastq-dump.cwl/fasta"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 32,
                        "prefix": "--helicos"
                    },
                    "doc": "Helicos style defline\n",
                    "id": "#fastq-dump.cwl/helicos"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#fastq-dump.cwl/matepair_distance/distance",
                            "symbols": [
                                "#fastq-dump.cwl/matepair_distance/distance/from-to",
                                "#fastq-dump.cwl/matepair_distance/distance/unknown"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--matepair-distance"
                    },
                    "doc": "Filter by distance beiween matepairs.\nUse \"unknown\" to find matepairs split\nbetween the references. Use from-to to limit\nmatepair distance on the same reference\n",
                    "id": "#fastq-dump.cwl/matepair_distance"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--maxSpotId"
                    },
                    "doc": "Maximum spot id\n",
                    "id": "#fastq-dump.cwl/max_spot_id"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--minReadLen"
                    },
                    "doc": "Filter by sequence length >= <len>\n",
                    "id": "#fastq-dump.cwl/min_read_len"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--minSpotId"
                    },
                    "doc": "Minimum spot id\n",
                    "id": "#fastq-dump.cwl/min_spot_id"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 27,
                        "prefix": "--offset"
                    },
                    "doc": "Offset to use for quality conversion, default is 33\n",
                    "id": "#fastq-dump.cwl/offset"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 30,
                        "prefix": "--origfmt"
                    },
                    "doc": "Defline contains only original sequence name\n",
                    "id": "#fastq-dump.cwl/origfmt"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--qual-filter"
                    },
                    "doc": "Filter used in early 1000 Genomes data: no sequences starting or ending with >= 10N\n",
                    "id": "#fastq-dump.cwl/qual_filter"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--qual-filter-1"
                    },
                    "doc": "Filter used in current 1000 Genomes data\n",
                    "id": "#fastq-dump.cwl/qual_filter_1"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 31,
                        "prefix": "--readids"
                    },
                    "doc": "Append read id after spot id as 'accession.spot.readid' on defline\n",
                    "id": "#fastq-dump.cwl/readids"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--skip-technical"
                    },
                    "doc": "Dump only biological reads\n",
                    "id": "#fastq-dump.cwl/skip_technical"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 21,
                        "prefix": "--split-3"
                    },
                    "doc": "Legacy 3-file splitting for mate-pairs:\nFirst biological reads satisfying dumping\nconditions are placed in files *_1.fastq and\n*_2.fastq If only one biological read is\npresent it is placed in *.fastq Biological\nreads and above are ignored.\n",
                    "id": "#fastq-dump.cwl/split_3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 20,
                        "prefix": "--split-files"
                    },
                    "doc": "Dump each read into separate file.\nFiles will receive suffix corresponding to read number\n",
                    "id": "#fastq-dump.cwl/split_files"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--split-spot"
                    },
                    "doc": "Split spots into individual reads\n",
                    "id": "#fastq-dump.cwl/split_spot"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 60
                    },
                    "doc": "Input file\n",
                    "id": "#fastq-dump.cwl/sra_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 29,
                        "prefix": "--suppress-qual-for-cskey"
                    },
                    "doc": "supress quality-value for cskey\n",
                    "id": "#fastq-dump.cwl/suppress_qual_for_cskey"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--unaligned"
                    },
                    "doc": "Dump only unaligned sequences\n",
                    "id": "#fastq-dump.cwl/unaligned"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  return [\n      inputs.sra_file.basename.split(\".\")[0] + \".fastq\",\n      inputs.sra_file.basename.split(\".\")[0] + \"_1.fastq\"\n    ];\n}\n"
                    },
                    "id": "#fastq-dump.cwl/fastq_file_1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return inputs.sra_file.basename.split(\".\")[0] + \"_2.fastq\";\n}\n"
                    },
                    "id": "#fastq-dump.cwl/fastq_file_2"
                }
            ],
            "baseCommand": [
                "fastq-dump"
            ],
            "doc": "Tool runs fastq-dump from NCBI SRA toolkit\nSupports only file inputs.\nOutput file names are formed on the base of `sra_file` input basename.\n",
            "id": "#fastq-dump.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#sratoolkit-metadata.yaml",
                "http://schema.org/name": "sratoolkit",
                "http://schema.org/about": "The SRA Toolkit and SDK from NCBI is a collection of tools and libraries for using data in the INSDC Sequence Read Archives\n",
                "http://schema.org/url": "https://trace.ncbi.nlm.nih.gov/Traces/sra/sra.cgi?view=toolkit_doc",
                "http://schema.org/codeRepository": "https://github.com/ncbi/sra-tools",
                "http://schema.org/license": [
                    "United States Government Work"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "2.8.2-1",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C",
                "http://schema.org/discussionUrl": [
                    "https://github.com/ncbi/sra-tools/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "National Center for Biotechnology Information",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "SRA Toolkit Development Team"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "fastq-dump",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/fastq-dump.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  fastq-dump [options] <path> [<path>...]\n  fastq-dump [options] <accession>\n\nINPUT\n  -A|--accession <accession>       Replaces accession derived from <path> in\n                                   filename(s) and deflines (only for single\n                                   table dump)\n  --table <table-name>             Table name within cSRA object, default is\n                                   \"SEQUENCE\"\n\nPROCESSING\n\nRead Splitting                     Sequence data may be used in raw form or\n                                     split into individual reads\n  --split-spot                     Split spots into individual reads\n\nFull Spot Filters                  Applied to the full spot independently\n                                     of --split-spot\n  -N|--minSpotId <rowid>           Minimum spot id\n  -X|--maxSpotId <rowid>           Maximum spot id\n  --spot-groups <[list]>           Filter by SPOT_GROUP (member): name[,...]\n  -W|--clip                        Clip adapter sequences\n\nCommon Filters                     Applied to spots when --split-spot is not\n                                     set, otherwise - to individual reads\n  -M|--minReadLen <len>            Filter by sequence length >= <len>\n  -R|--read-filter <[filter]>      Split into files by READ_FILTER value\n                                   optionally filter by value:\n                                   pass|reject|criteria|redacted\n  -E|--qual-filter                 Filter used in early 1000 Genomes data: no\n                                   sequences starting or ending with >= 10N\n  --qual-filter-1                  Filter used in current 1000 Genomes data\n\nFilters based on alignments        Filters are active when alignment\n                                     data are present\n  --aligned                        Dump only aligned sequences\n  --unaligned                      Dump only unaligned sequences\n  --aligned-region <name[:from-to]>  Filter by position on genome. Name can\n                                   either be accession.version (ex:\n                                   NC_000001.10) or file specific name (ex:\n                                   \"chr1\" or \"1\"). \"from\" and \"to\" are 1-based\n                                   coordinates\n  --matepair-distance <from-to|unknown>  Filter by distance between matepairs.\n                                   Use \"unknown\" to find matepairs split\n                                   between the references. Use from-to to limit\n                                   matepair distance on the same reference\n\nFilters for individual reads       Applied only with --split-spot set\n  --skip-technical                 Dump only biological reads\n\nOUTPUT\n  -O|--outdir <path>               Output directory, default is working\n                                   directory '.' )\n  -Z|--stdout                      Output to stdout, all split data become\n                                   joined into single stream\n  --gzip                           Compress output using gzip\n  --bzip2                          Compress output using bzip2\n\nMultiple File Options              Setting these options will produce more\n                                     than 1 file, each of which will be suffixed\n                                     according to splitting criteria.\n  --split-files                    Dump each read into separate file.Files\n                                   will receive suffix corresponding to read\n                                   number\n  --split-3                        Legacy 3-file splitting for mate-pairs:\n                                   First biological reads satisfying dumping\n                                   conditions are placed in files *_1.fastq and\n                                   *_2.fastq If only one biological read is\n                                   present it is placed in *.fastq Biological\n                                   reads and above are ignored.\n  -G|--spot-group                  Split into files by SPOT_GROUP (member name)\n  -R|--read-filter <[filter]>      Split into files by READ_FILTER value\n                                   optionally filter by value:\n                                   pass|reject|criteria|redacted\n  -T|--group-in-dirs               Split into subdirectories instead of files\n  -K|--keep-empty-files            Do not delete empty files\n\nFORMATTING\n\nSequence\n  -C|--dumpcs <[cskey]>            Formats sequence using color space (default\n                                   for SOLiD),\"cskey\" may be specified for\n                                   translation\n  -B|--dumpbase                    Formats sequence using base space (default\n                                   for other than SOLiD).\n\nQuality\n  -Q|--offset <integer>            Offset to use for quality conversion,\n                                   default is 33\n  --fasta <[line width]>           FASTA only, no qualities, optional line\n                                   wrap width (set to zero for no wrapping)\n  --suppress-qual-for-cskey        suppress quality-value for cskey\n\nDefline\n  -F|--origfmt                     Defline contains only original sequence name\n  -I|--readids                     Append read id after spot id as\n                                   'accession.spot.readid' on defline\n  --helicos                        Helicos style defline\n  --defline-seq <fmt>              Defline format specification for sequence.\n  --defline-qual <fmt>             Defline format specification for quality.\n                                   <fmt> is string of characters and/or\n                                   variables. The variables can be one of: $ac\n                                   - accession, $si spot id, $sn spot\n                                   name, $sg spot group (barcode), $sl spot\n                                   length in bases, $ri read number, $rn\n                                   read name, $rl read length in bases. '[]'\n                                   could be used for an optional output: if\n                                   all vars in [] yield empty values whole\n                                   group is not printed. Empty value is empty\n                                   string or for numeric variables. Ex:\n                                   @$sn[_$rn]/$ri '_$rn' is omitted if name\n                                   is empty\n\nOTHER:\n  --disable-multithreading         disable multithreading\n  -h|--help                        Output brief explanation of program usage\n  -V|--version                     Display the version of the program\n  -L|--log-level <level>           Logging level as number or enum string One\n                                   of (fatal|sys|int|err|warn|info) or (0-5)\n                                   Current/default is warn\n  -v|--verbose                     Increase the verbosity level of the program\n                                   Use multiple times for more verbosity\n  --ncbi_error_report              Control program execution environment\n                                   report generation (if implemented). One of\n                                   (never|error|always). Default is error\n  --legacy-report                  use legacy style 'Written spots' for tool\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/fastqc:v0.11.5"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--adapters"
                    },
                    "doc": "Specifies a non-default file which contains the list of\nadapter sequences which will be explicity searched against\nthe library. The file must contain sets of named adapters\nin the form name[tab]sequence.  Lines prefixed with a hash\nwill be ignored.\n",
                    "id": "#fastqc.cwl/adapters"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--casava"
                    },
                    "doc": "Files come from raw casava output. Files in the same sample\ngroup (differing only by the group number) will be analysed\nas a set rather than individually. Sequences with the filter\nflag set in the header will be excluded from the analysis.\nFiles must have the same names given to them by casava\n(including being gzipped and ending with .gz) otherwise they\nwon't be grouped together correctly.\n",
                    "id": "#fastqc.cwl/casava"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--contaminants"
                    },
                    "doc": "Specifies a non-default file which contains the list of\ncontaminants to screen overrepresented sequences against.\nThe file must contain sets of named contaminants in the\nform name[tab]sequence.  Lines prefixed with a hash will\nbe ignored.\n",
                    "id": "#fastqc.cwl/contaminants"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 50
                    },
                    "doc": "Input bam,sam,bam_mapped,sam_mapped or fastq file\n",
                    "id": "#fastqc.cwl/fastq_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#fastqc.cwl/format_enum/format",
                            "symbols": [
                                "#fastqc.cwl/format_enum/format/bam",
                                "#fastqc.cwl/format_enum/format/sam",
                                "#fastqc.cwl/format_enum/format/bam_mapped",
                                "#fastqc.cwl/format_enum/format/sam_mapped",
                                "#fastqc.cwl/format_enum/format/fastq"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--format"
                    },
                    "doc": "Bypasses the normal sequence file format detection and\nforces the program to use the specified format.  Valid\nformats are bam,sam,bam_mapped,sam_mapped and fastq\n",
                    "id": "#fastqc.cwl/format_enum"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--nogroup"
                    },
                    "doc": "Disable grouping of bases for reads >50bp. All reports will\nshow data for every base in the read.  WARNING: Using this\noption will cause fastqc to crash and burn if you use it on\nreally long reads, and your plots may end up a ridiculous size.\nYou have been warned!\n",
                    "id": "#fastqc.cwl/hide_group"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--kmers"
                    },
                    "doc": "Specifies the length of Kmer to look for in the Kmer content\nmodule. Specified Kmer length must be between 2 and 10. Default\nlength is 7 if not specified.\n",
                    "id": "#fastqc.cwl/kmers"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--limits"
                    },
                    "doc": "Specifies a non-default file which contains a set of criteria\nwhich will be used to determine the warn/error limits for the\nvarious modules.  This file can also be used to selectively\nremove some modules from the output all together.  The format\nneeds to mirror the default limits.txt file found in the\nConfiguration folder.\n",
                    "id": "#fastqc.cwl/limits"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--nofilter"
                    },
                    "doc": "If running with --casava then don't remove read flagged by\ncasava as poor quality when performing the QC analysis.\n",
                    "id": "#fastqc.cwl/nofilter"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--threads"
                    },
                    "doc": "Specifies the number of files which can be processed\nsimultaneously.  Each thread will be allocated 250MB of\nmemory so you shouldn't run more threads than your\navailable memory will cope with, and not more than\n6 threads on a 32 bit machine\n",
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return \"*/summary.txt\";\n}\n"
                    },
                    "id": "#fastqc.cwl/summary_file"
                },
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.zip"
                    },
                    "id": "#fastqc.cwl/zipped_file"
                }
            ],
            "baseCommand": [
                "fastqc",
                "--extract",
                "--outdir",
                "."
            ],
            "doc": "Tool runs FastQC from Babraham Bioinformatics\n",
            "id": "#fastqc.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#fastqc-metadata.yaml",
                "http://schema.org/name": "fastqc",
                "http://schema.org/about": "FastQC is a program designed to spot potential problems in high througput sequencing datasets.\nIt runs a set of analyses on one or more raw sequence files in fastq or bam format and produces\na report which summarises the results.\n",
                "http://schema.org/url": "http://www.bioinformatics.babraham.ac.uk/projects/fastqc/",
                "http://schema.org/codeRepository": "https://github.com/s-andrews/FastQC/releases",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.11.5",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "Java",
                "http://schema.org/discussionUrl": [
                    "https://github.com/s-andrews/FastQC/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Babraham Bioinformatics",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Simon Andrews"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "fastqc",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/fastqc.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "SYNOPSIS\n\n    fastqc seqfile1 seqfile2 .. seqfileN\n\n    fastqc [-o output dir] [--(no)extract] [-f fastq|bam|sam]\n           [-c contaminant file] seqfile1 .. seqfileN\n\nDESCRIPTION\n\n    FastQC reads a set of sequence files and produces from each one a quality\n    control report consisting of a number of different modules, each one of\n    which will help to identify a different potential type of problem in your\n    data.\n\n    If no files to process are specified on the command line then the program\n    will start as an interactive graphical application.  If files are provided\n    on the command line then the program will run with no user interaction\n    required.  In this mode it is suitable for inclusion into a standardised\n    analysis pipeline.\n\n    The options for the program as as follows:\n\n    -h --help       Print this help file and exit\n\n    -v --version    Print the version of the program and exit\n\n    -o --outdir     Create all output files in the specified output directory.\n                    Please note that this directory must exist as the program\n                    will not create it.  If this option is not set then the\n                    output file for each sequence file is created in the same\n                    directory as the sequence file which was processed.\n\n    --casava        Files come from raw casava output. Files in the same sample\n                    group (differing only by the group number) will be analysed\n                    as a set rather than individually. Sequences with the filter\n                    flag set in the header will be excluded from the analysis.\n                    Files must have the same names given to them by casava\n                    (including being gzipped and ending with .gz) otherwise they\n                    won't be grouped together correctly.\n\n    --nano          Files come from naopore sequences and are in fast5 format. In\n                    this mode you can pass in directories to process and the program\n                    will take in all fast5 files within those directories and produce\n                    a single output file from the sequences found in all files.\n\n    --nofilter      If running with --casava then don't remove read flagged by\n                    casava as poor quality when performing the QC analysis.\n\n    --extract       If set then the zipped output file will be uncompressed in\n                    the same directory after it has been created.  By default\n                    this option will be set if fastqc is run in non-interactive\n                    mode.\n\n    -j --java       Provides the full path to the java binary you want to use to\n                    launch fastqc. If not supplied then java is assumed to be in\n                    your path.\n\n    --noextract     Do not uncompress the output file after creating it.  You\n                    should set this option if you do not wish to uncompress\n                    the output when running in non-interactive mode.\n\n    --nogroup       Disable grouping of bases for reads >50bp. All reports will\n                    show data for every base in the read.  WARNING: Using this\n                    option will cause fastqc to crash and burn if you use it on\n                    really long reads, and your plots may end up a ridiculous size.\n                    You have been warned!\n\n    -f --format     Bypasses the normal sequence file format detection and\n                    forces the program to use the specified format.  Valid\n                    formats are bam,sam,bam_mapped,sam_mapped and fastq\n\n    -t --threads    Specifies the number of files which can be processed\n                    simultaneously.  Each thread will be allocated 250MB of\n                    memory so you shouldn't run more threads than your\n                    available memory will cope with, and not more than\n                    6 threads on a 32 bit machine\n\n    -c              Specifies a non-default file which contains the list of\n    --contaminants  contaminants to screen overrepresented sequences against.\n                    The file must contain sets of named contaminants in the\n                    form name[tab]sequence.  Lines prefixed with a hash will\n                    be ignored.\n\n    -a              Specifies a non-default file which contains the list of\n    --adapters      adapter sequences which will be explicity searched against\n                    the library. The file must contain sets of named adapters\n                    in the form name[tab]sequence.  Lines prefixed with a hash\n                    will be ignored.\n\n    -l              Specifies a non-default file which contains a set of criteria\n    --limits        which will be used to determine the warn/error limits for the\n                    various modules.  This file can also be used to selectively\n                    remove some modules from the output all together.  The format\n                    needs to mirror the default limits.txt file found in the\n                    Configuration folder.\n\n   -k --kmers       Specifies the length of Kmer to look for in the Kmer content\n                    module. Specified Kmer length must be between 2 and 10. Default\n                    length is 7 if not specified.\n\n   -q --quiet       Supress all progress messages on stdout and only report errors.\n\n   -d --dir         Selects a directory to be used for temporary files written when\n                    generating report images. Defaults to system temp directory if\n                    not specified.\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  var listing = []\n  if (inputs.fastq_file_upstream){\n    listing.push(inputs.fastq_file_upstream);\n  }\n  if (inputs.fastq_file_downstream){\n    listing.push(inputs.fastq_file_downstream);\n  }\n  return listing;\n}\n"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(input_file, ext) { let root = input_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_file.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/trimmomatic:v0.35"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search\nfor and remove these sequences in the input FASTQ file(s)\n",
                    "id": "#trimmomatic.cwl/adapters_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nif [ \"$0\" = \"true\" ]\nthen\n  echo \"Run trimmomatic\"\n  java \"${@:1}\"\nelse\n  echo \"Skip run trimmomatic\"\nfi\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bash function to run trimmomatic with all input parameters or skip it if trigger is false\n",
                    "id": "#trimmomatic.cwl/bash_script"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 104,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "doc": "<length>\nRemoves bases regardless of quality from the end of the read, so that the read has maximally\nthe specified length after this step has been performed. Steps performed after CROP might of\ncourse further shorten the read.\n<length>: The number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/crop_step"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 14
                    },
                    "doc": "FASTQ file for read R2 in Paired End mode\n",
                    "id": "#trimmomatic.cwl/fastq_file_downstream"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 13
                    },
                    "doc": "FASTQ file for input read (read R1 in Paired End mode)\n",
                    "id": "#trimmomatic.cwl/fastq_file_upstream"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 105,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "doc": "<length>\nRemoves the specified number of bases, regardless of quality, from the beginning of the read.\n<length>: The number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/headcrop_step"
                },
                {
                    "type": "string",
                    "doc": "<fastaWithAdaptersEtc>:<seed mismatches>:<palindrome clip threshold>:<simple clip threshold>:<minAdapterLength>:<keepBothReads>\nFind and remove Illumina adapters.\nREQUIRED:\n<fastaWithAdaptersEtc>: specifies the path to a fasta file containing all the adapters, PCR sequences etc.\nThe naming of the various sequences within this file determines how they are used. See below.\n<seedMismatches>: specifies the maximum mismatch count which will still allow a full match to be performed\n<palindromeClipThreshold>: specifies how accurate the match between the two 'adapter ligated' reads must be\nfor PE palindrome read alignment.\n<simpleClipThreshold>: specifies how accurate the match between any adapter etc. sequence must be against a read\nOPTIONAL:\n<minAdapterLength>: In addition to the alignment score, palindrome mode can verify\nthat a minimum length of adapter has been detected. If unspecified, this defaults to 8 bases,\nfor historical reasons. However, since palindrome mode has a very low false positive rate, this\ncan be safely reduced, even down to 1, to allow shorter adapter fragments to be removed.\n<keepBothReads>: After read-though has been detected by palindrome mode, and the\nadapter sequence removed, the reverse read contains the same sequence information as the\nforward read, albeit in reverse complement. For this reason, the default behaviour is to\nentirely drop the reverse read. By specifying \u201etrue\u201f for this parameter, the reverse read will\nalso be retained, which may be useful e.g. if the downstream tools cannot handle a\ncombination of paired and unpaired reads.\n",
                    "id": "#trimmomatic.cwl/illuminaclip_step_param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "id": "#trimmomatic.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 102,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "doc": "<quality>\nRemove low quality bases from the beginning. As long as a base has a value below this\nthreshold the base is removed and the next base will be investigated.\n<quality>: Specifies the minimum quality required to keep a base.\n",
                    "id": "#trimmomatic.cwl/leading_step"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "name": "#trimmomatic.cwl/lib_type/format",
                            "symbols": [
                                "#trimmomatic.cwl/lib_type/format/SE",
                                "#trimmomatic.cwl/lib_type/format/PE"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "doc": "SE|PE\nSingle End (SE) or Paired End (PE) mode\n",
                    "id": "#trimmomatic.cwl/lib_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-trimlog"
                    },
                    "doc": "<ouptut log file name>\nSpecifying a trimlog file creates a log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n<ouptut log file name>: filename for the generated output log file.\n",
                    "id": "#trimmomatic.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 106,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "doc": "<length>\nThis module removes reads that fall below the specified minimal length. If required, it should\nnormally be after all other processing steps. Reads removed by this step will be counted and\nincluded in the \u201edropped reads\u201f count presented in the trimmomatic summary.\n<length>:  Specifies the minimum length of reads to be kept\n",
                    "id": "#trimmomatic.cwl/minlen_step"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#trimmomatic.cwl/phred/phred",
                            "symbols": [
                                "#trimmomatic.cwl/phred/phred/33",
                                "#trimmomatic.cwl/phred/phred/64"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 9
                    },
                    "doc": "\"33\"|\"64\"\n-phred33 (\"33\") or -phred64 (\"64\") specifies the base quality encoding. Default: -phred64\n",
                    "id": "#trimmomatic.cwl/phred"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "SLIDINGWINDOW:",
                        "separate": false
                    },
                    "doc": "<windowSize>:<requiredQuality>\nPerform a sliding window trimming, cutting once the average quality within the window falls\nbelow a threshold. By considering multiple bases, a single poor quality base will not cause the\nremoval of high quality data later in the read.\n<windowSize>: specifies the number of bases to average across\n<requiredQuality>: specifies the average quality required\n",
                    "id": "#trimmomatic.cwl/sliding_window_step"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-threads"
                    },
                    "doc": "Number of threads\n",
                    "id": "#trimmomatic.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 107,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.\n",
                    "id": "#trimmomatic.cwl/tophred33_step"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 107,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.\n",
                    "id": "#trimmomatic.cwl/tophred64_step"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 103,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "doc": "<quality>\nRemove low quality bases from the end. As long as a base has a value below this threshold\nthe base is removed and the next base (which as trimmomatic is starting from the 3\u201f prime end\nwould be base preceding the just removed base) will be investigated. This approach can be\nused removing the special illumina \u201elow quality segment\u201f regions (which are marked with\nquality score of 2), but we recommend Sliding Window or MaxInfo instead\n<quality>: Specifies the minimum quality required to keep a base.\n",
                    "id": "#trimmomatic.cwl/trailing_step"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "${ return self ? \"true\" : \"false\" }\n"
                    },
                    "doc": "If true - run trimmomatic, if false - return input fastq files, previously staged into output directory.\nUse valueFrom to return string instead of boolean, because if return boolean False, argument is not printed\n",
                    "id": "#trimmomatic.cwl/trigger"
                },
                {
                    "type": "string",
                    "default": "/usr/share/java/trimmomatic.jar",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-jar"
                    },
                    "id": "#trimmomatic.cwl/trimmomatic_jar_path"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-validatePairs",
                        "position": 10
                    },
                    "doc": "Run -validatePairs. No official documentation\n",
                    "id": "#trimmomatic.cwl/validate_pairs"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.lib_type==\"PE\"){\n    return inputs.trigger?default_output_filename(inputs.fastq_file_downstream,'.trimmed.fastq'):inputs.fastq_file_downstream.basename;\n  }\n  return null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/downstream_trimmed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_downstream, '.unpaired.trimmed.fastq'):null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/downstream_trimmed_unpaired_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.log_filename)"
                    },
                    "doc": "Trimmomatic Log file.\n",
                    "id": "#trimmomatic.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  return inputs.trigger?default_output_filename(inputs.fastq_file_upstream, '.trimmed.fastq'):inputs.fastq_file_upstream.basename;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/upstream_trimmed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_upstream, '.unpaired.trimmed.fastq'):null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/upstream_trimmed_unpaired_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "$(default_output_filename(inputs.fastq_file_upstream, '.trimmed.fastq'))",
                    "position": 15
                },
                {
                    "valueFrom": "$(inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_upstream, '.trimmed.unpaired.fastq'):null)",
                    "position": 16
                },
                {
                    "valueFrom": "$(inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_downstream, '.trimmed.fastq'):null)",
                    "position": 17
                },
                {
                    "valueFrom": "$(inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_downstream, '.trimmed.unpaired.fastq'):null)",
                    "position": 18
                },
                {
                    "valueFrom": "$(\"ILLUMINACLIP:\" + inputs.adapters_file.path + \":\"+ inputs.illuminaclip_step_param)",
                    "position": 100
                }
            ],
            "doc": "Tool runs trimmomatic with ILLUMINACLIP step by default.\n\n`-basein` and `-baseout` inputs are skipped.\n\nIf set `lib_type` to `PE`, both of the inputs `fastq_file_upstream` and `fastq_file_downstream` shoul be provided.\n\nIf input `trigger` is set to `true` or isn't set at all (`true` is used by default), run `trimmomatic` and return\nFASTQ file[s] with trimmed adapters, alongside with the uppaired reads FASTQ files (if `lib_type` is set to `PE` and\nsuch files are present after running `trimmomatic`)\nIf input `trigger` is set to `false`, return unchanged `fastq_file_upstream` and `fastq_file_downstream`, previously\nstaged into output directory.\n\nBefore execution `baseCommand`, `fastq_file_upstream` and `fastq_file_downstream` (if provided) are staged into directory\nset as docker parameter `--workdir` (tool's output directory), using `InitialWorkDirRequirement`. They are mount\nto docker container with `ro` mode as part of `--workdir`, because all generated files will have `trimmed` suffix\nin their names, so the staged files will not be overwritten.\n\nTrigger logic is implemented in a bash scripts set by default as `bash_script` input. If the first argument $0 (which is\n`trigger` input) is true, run `trimmomatic` with the rest of the arguments. If $0 is not true, skip `trimmomatic` and\nreturn `fastq_file_upstream` and `fastq_file_downstream` (if provided) staged into output directory.\n\nInput `trigger` is Boolean, but returns String, because of `valueFrom` field. The `valueFrom` is used, because if `trigger`\nis false, cwl-runner doesn't append this argument at all to the the `baseCommand` - new feature of CWL v1.0.2. Alternatively,\n`prefix` field could be used, but it causes changing in script logic.\n\n`default_output_name` function is used for generating output filename based on `input_file.basename` and provided\nextension.\n",
            "id": "#trimmomatic.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#trimmomatic-metadata.yaml",
                "http://schema.org/name": "trimmomatic",
                "http://schema.org/about": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop\nIllumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem\ndepending on the library preparation and downstream application.\n",
                "http://schema.org/url": "http://www.usadellab.org/cms/?page=trimmomatic",
                "http://schema.org/codeRepository": "http://www.usadellab.org/cms/uploads/supplementary/Trimmomatic/Trimmomatic-Src-0.35.zip",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.35",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "Java",
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "USADELLAB",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bolger AM"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Lohse M"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Usadel B"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "trimmomatic",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/trimmomatic.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n       PE [-threads <threads>] [-phred33|-phred64] [-trimlog <trimLogFile>] [-quiet] [-validatePairs] [-basein <inputBase> | <inputFile1> <inputFile2>] [-baseout <outputBase> | <outputFile1P> <outputFile1U> <outputFile2P> <outputFile2U>] <trimmer1>...\n   or:\n       SE [-threads <threads>] [-phred33|-phred64] [-trimlog <trimLogFile>] [-quiet] <inputFile> <outputFile> <trimmer1>...\n"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ]
}
